diff src/globals.h @ 14515:3648e74dd523 v8.1.0271

patch 8.1.0271: 'incsearch' doesn't work for :s, :g or :v commit https://github.com/vim/vim/commit/b0acacd767a2b0618a7f3c08087708f4329580d0 Author: Bram Moolenaar <Bram@vim.org> Date: Sat Aug 11 16:40:43 2018 +0200 patch 8.1.0271: 'incsearch' doesn't work for :s, :g or :v Problem: 'incsearch' doesn't work for :s, :g or :v. Solution: Also use 'incsearch' for other commands that use a pattern.
author Christian Brabandt <cb@256bit.org>
date Sat, 11 Aug 2018 16:45:05 +0200
parents 0a69e6e708f9
children 4caa51067cb8
line wrap: on
line diff
--- a/src/globals.h
+++ b/src/globals.h
@@ -345,9 +345,13 @@ EXTERN int	t_colors INIT(= 0);	    /* in
  * a match within one line), search_match_endcol the column number of the
  * character just after the match in the last line.
  */
-EXTERN int	highlight_match INIT(= FALSE);	/* show search match pos */
-EXTERN linenr_T	search_match_lines;		/* lines of of matched string */
-EXTERN colnr_T	search_match_endcol;		/* col nr of match end */
+EXTERN int	highlight_match INIT(= FALSE);	// show search match pos
+EXTERN linenr_T	search_match_lines;		// lines of of matched string
+EXTERN colnr_T	search_match_endcol;		// col nr of match end
+#ifdef FEAT_SEARCH_EXTRA
+EXTERN linenr_T	search_first_line INIT(= 0);	  // for :{FIRST},{last}s/pat
+EXTERN linenr_T	search_last_line INIT(= MAXLNUM); // for :{first},{LAST}s/pat
+#endif
 
 EXTERN int	no_smartcase INIT(= FALSE);	/* don't use 'smartcase' once */